summaryrefslogtreecommitdiff
path: root/src/tools/wasm2js.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/tools/wasm2js.cpp')
-rw-r--r--src/tools/wasm2js.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/tools/wasm2js.cpp b/src/tools/wasm2js.cpp
index b8e2daa39..7fa56c810 100644
--- a/src/tools/wasm2js.cpp
+++ b/src/tools/wasm2js.cpp
@@ -809,7 +809,7 @@ void AssertionEmitter::emit() {
int main(int argc, const char* argv[]) {
Wasm2JSBuilder::Flags flags;
OptimizationOptions options("wasm2js",
- "Transform .wasm/.wast files to asm.js");
+ "Transform .wasm/.wat files to asm.js");
options
.add("--output",
"-o",
@@ -873,7 +873,7 @@ int main(int argc, const char* argv[]) {
try {
// If the input filename ends in `.wasm`, then parse it in binary form,
// otherwise assume it's a `*.wast` file and go from there.
//
// Note that we're not using the built-in `ModuleReader` which will also do
// similar logic here because when testing JS files we use the
@@ -873,7 +873,7 @@ int main(int argc, const char* argv[]) {
try {
// If the input filename ends in `.wasm`, then parse it in binary form,
- // otherwise assume it's a `*.wast` file and go from there.
+ // otherwise assume it's a `*.wat` file and go from there.
//
// Note that we're not using the built-in `ModuleReader` which will also do